@@ -25,19 +25,19 @@
 #ifndef BUDDYCONTENT_H
 #define BUDDYCONTENT_H
 
-#include <QtGui>
 
 class BuddyContent
 {
 
 public:
-	BuddyContent(QString m_name, QString m_hostname, int m_port, QString m_SN, QWidget* parent) : name(m_name), 
-			hostname(m_hostname), port(m_port), SN(m_SN) {};
+	BuddyContent(QString m_name, QString m_hostname, int m_port, QString m_SN, QString m_llname, QWidget* parent) : name(m_name), 	hostname(m_hostname), port(m_port), SN(m_SN) ,llname(m_llname) {};
 	
 	QString name;
 	QString hostname;
 	int port;
 	QString SN;
+	QString llname;
+	QString http;
 
 };
 
