@@ -22,6 +22,8 @@
  *
 */
 
+#include <KDebug>
+
 #include "buddylist.h"
 
 
@@ -36,7 +38,8 @@ BuddyList::BuddyList(QObject* parent)
 	count = 0;
 	buddyVector = new QVector<BuddyContent*>;
 
-	icqListWidget = 0;
+	kopeteListWidget = 0;
+	listWidgets = 0;
 	buddyListWidget = new QListWidget();
 	
 	buddyListWidget->setMouseTracking(true);
@@ -45,12 +48,15 @@ BuddyList::BuddyList(QObject* parent)
 	buddyListWidget->setViewMode(QListView::IconMode);
 	buddyListWidget->setResizeMode(QListView::Adjust);
 	buddyListWidget->setEnabled(true);
+	buddyListWidget->setDragEnabled(false);
+	
 
 	tabWidget->clear();	
-	tabWidget->addTab(buddyListWidget, SmallIcon("network-workgroup"), i18n("LAN"));
+	tabWidget->addTab(buddyListWidget, KIcon("network-workgroup"), i18n("LAN"));
 	
 	buddyItemOld = 0;
 	dbus = 0;
+        m_dialog = 0;
 	
 	connect(buddyListWidget, SIGNAL(itemEntered(QListWidgetItem*)),this,SLOT(slotItemEntered(QListWidgetItem*)));
 //	connect(buddyListWidget, SIGNAL(itemSelectionChanged()),this,SLOT(slotItemSelectionChanged()));
@@ -62,13 +68,18 @@ BuddyList::BuddyList(QObject* parent)
 
 BuddyList::~BuddyList()
 {
-	qDebug() << "deleting buddylist";
+	kDebug() << "deleting buddylist";
 
-	if (buddyListWidget)
+	if (buddyListWidget) {
+		kDebug() << "buddyListWidget deleted";
 		delete buddyListWidget;
+	}
 
-	if (icqListWidget)
-		delete icqListWidget;
+//	if (kopeteListWidget)
+//		delete kopeteListWidget;
+
+	if (listWidgets)
+		delete listWidgets;
 
 	if (buddyVector)
 		delete buddyVector;
@@ -76,22 +87,27 @@ BuddyList::~BuddyList()
 	if (dbus)
 		delete dbus;
 
-	if (buddyItemOld)
-		delete buddyItemOld;
+//	if (buddyItemOld)
+//		delete buddyItemOld;
+
+        if (m_dialog)
+                delete m_dialog;
 }
 
 void BuddyList::initDefaultBuddyList(QString name)
 {	
-	checkICQStatus();	
+	checkKopeteStatus();	
 
 	buddyListWidget->setEnabled(true);
 	connect(buddyListWidget, SIGNAL(itemClicked(QListWidgetItem*)),this,SLOT(slotPopupMenu(QListWidgetItem*)));
 
-	if (icqListWidget != 0) {
-		connect(icqListWidget, SIGNAL(itemClicked(QListWidgetItem*)),this,SLOT(slotPopupKopeteMenu(QListWidgetItem*)));
+	if (listWidgets != 0) {
+		QList<QListWidget*>::iterator acc;
+		for(acc = listWidgets->begin(); acc != listWidgets->end(); ++acc) 
+			connect(*acc, SIGNAL(itemClicked(QListWidgetItem*)),this,SLOT(slotPopupKopeteMenu(QListWidgetItem*)));
 	}
-
 	m_userName = name;
+        m_hostname = QHostInfo::localHostName();
 	show();
 }
 
@@ -99,31 +115,65 @@ void BuddyList::initDefaultBuddyList(QString name)
 void BuddyList::initSendClipBuddyList(QString clipEntry, QString username)
 {
 	disconnect(buddyListWidget, SIGNAL(itemClicked(QListWidgetItem*)),this,SLOT(slotPopupMenu(QListWidgetItem*)));
-	disconnect(icqListWidget, SIGNAL(itemClicked(QListWidgetItem*)),this,SLOT(slotPopupKopeteMenu(QListWidgetItem*)));
+
+	if (listWidgets != 0) {
+		QList<QListWidget*>::iterator acc;
+                for(acc = listWidgets->begin(); acc != listWidgets->end(); ++acc)
+			disconnect(*acc, SIGNAL(itemClicked(QListWidgetItem*)),this,SLOT(slotPopupKopeteMenu(QListWidgetItem*)));
+	}
 
 	buddyListWidget->setEnabled(true);
 	m_clipEntry = clipEntry;
 	connect(buddyListWidget, SIGNAL(itemClicked(QListWidgetItem*)),this,SLOT(slotSendClip(QListWidgetItem*)));
 	m_userName = username;
+        m_hostname = QHostInfo::localHostName();
+	show();
+}
+
+void BuddyList::initSendNoteBuddyList(QString noteEntry, QString username)
+{
+	disconnect(buddyListWidget, SIGNAL(itemClicked(QListWidgetItem*)),this,SLOT(slotPopupMenu(QListWidgetItem*)));
+
+	if (listWidgets != 0) {
+		QList<QListWidget*>::iterator acc;
+                for(acc = listWidgets->begin(); acc != listWidgets->end(); ++acc)
+			disconnect(*acc, SIGNAL(itemClicked(QListWidgetItem*)),this,SLOT(slotPopupKopeteMenu(QListWidgetItem*)));
+	}
+
+	buddyListWidget->setEnabled(true);
+	m_noteEntry = noteEntry;
+	connect(buddyListWidget, SIGNAL(itemClicked(QListWidgetItem*)),this,SLOT(slotSendNote(QListWidgetItem*)));
+	m_userName = username;
+        m_hostname = QHostInfo::localHostName();
 	show();
 }
 
 
 void BuddyList::initSendFileBuddyList(QString file, QString username)
 {
-	checkICQStatus();	
+	checkKopeteStatus();	
 	disconnect(buddyListWidget, SIGNAL(itemClicked(QListWidgetItem*)),this,SLOT(slotPopupMenu(QListWidgetItem*)));
-        disconnect(icqListWidget, SIGNAL(itemClicked(QListWidgetItem*)),this,SLOT(slotPopupKopeteMenu(QListWidgetItem*)));
+	if (listWidgets != 0) {
+		QList<QListWidget*>::iterator acc;
+                for(acc = listWidgets->begin(); acc != listWidgets->end(); ++acc)
+			disconnect(*acc, SIGNAL(itemClicked(QListWidgetItem*)),this,SLOT(slotPopupKopeteMenu(QListWidgetItem*)));
+	}
 
 	buddyListWidget->setEnabled(true);
-	qDebug() << "initSendFileBuddyList";
+	kDebug() << "initSendFileBuddyList";
 	m_fileName = file;
 	connect(buddyListWidget, SIGNAL(itemClicked(QListWidgetItem*)),this,SLOT(slotSendFileDirect(QListWidgetItem*)));
 
-	if (icqListWidget != 0) {
-		connect(icqListWidget, SIGNAL(itemClicked(QListWidgetItem*)),this,SLOT(slotSendFileDirectICQ(QListWidgetItem*)));
+	if (listWidgets != 0) {
+		QList<QListWidget*>::iterator acc;
+                for(acc = listWidgets->begin(); acc != listWidgets->end(); ++acc)
+			connect(*acc, SIGNAL(itemClicked(QListWidgetItem*)),this,SLOT(slotSendFileDirectKopete(QListWidgetItem*)));
 	}
+
+
+
 	m_userName = username;
+        m_hostname = QHostInfo::localHostName();
 	show();
 }
 
@@ -136,6 +186,7 @@ void BuddyList::addService(QMap<QString, QByteArray> info)
 	QString username = info["User Name"];
 	QString hostname = info["Machine Name"];
 	QString port = info["port"];
+	QString llname = info["llname"];
 	
 	if (!buddyVector->isEmpty())
 		for (int i = 0; i < buddyVector->count(); i++) {
@@ -144,10 +195,10 @@ void BuddyList::addService(QMap<QString, QByteArray> info)
 				return;
 
 		}
-	newBuddyContent = new BuddyContent(username,hostname,port.toInt(),info["SN"],this);
+	newBuddyContent = new BuddyContent(username,hostname,port.toInt(),info["SN"],info["llname"],this);
 	buddyVector->push_back(newBuddyContent);
 
-	buddy = new QListWidgetItem(KIcon("user"), QString(username + "@" + hostname),buddyListWidget);
+	buddy = new QListWidgetItem(KIcon("user-identity"), QString(username + "@" + hostname),buddyListWidget);
 //	buddy = new QListWidgetItem(KIcon("user"), QString(username + "@" + hostname + ":" + port),buddyListWidget);
 	buddyListWidget->addItem(buddy);
 
@@ -157,20 +208,33 @@ void BuddyList::addService(QMap<QString, QByteArray> info)
 void BuddyList::delService(QString sn)
 {
 
-	qDebug() << "Deleting Buddy!";
+	kDebug() << "Deleting Buddy!";
 	if (!buddyVector->isEmpty())
 		for (int i = 0; i < buddyVector->count(); i++) {
 			tmpBuddyContent = buddyVector->at(i);
-	//		qDebug() << "Name:" << tmpBuddyContent->name << " host: " << tmpBuddyContent->hostname;
+	//		kDebug() << "Name:" << tmpBuddyContent->name << " host: " << tmpBuddyContent->hostname;
 
 			if (tmpBuddyContent->SN == sn) {
-				qDebug() << "take item at pos: " << i;
+				kDebug() << "take item at pos: " << i;
 				buddyListWidget->takeItem(i);
 				buddyVector->remove(i);
 			}
 		}
 }
 
+void BuddyList::addHttpService(QString srv, QString addr)
+{
+	if (!httpList.contains(srv))
+		httpList[srv] = addr;
+
+}
+
+void BuddyList::delHttpService(QString srv)
+{
+	if (httpList.contains(srv)) {
+		httpList.remove(srv);
+	}
+}
 
 void BuddyList::slotItemEntered(QListWidgetItem* buddyItem)
 {
@@ -186,7 +250,7 @@ void BuddyList::slotItemEntered(QListWidgetItem* buddyItem)
 
 void BuddyList::slotItemSelectionChanged()
 {
-	qDebug() << "changed";
+	kDebug() << "changed";
 
 
 
@@ -194,7 +258,7 @@ void BuddyList::slotItemSelectionChanged()
 
 void BuddyList::slotPopupMenu(QListWidgetItem* buddyItem)
 {
-
+	 disconnect(buddyListWidget, SIGNAL(itemClicked(QListWidgetItem*)),this,SLOT(slotPopupMenu(QListWidgetItem*)));
          buddyItem->setBackground(QColor("aliceblue"));
          buddyItem->setForeground(Qt::red);
 
@@ -203,18 +267,29 @@ void BuddyList::slotPopupMenu(QListWidgetItem* buddyItem)
 
          sendFileAction = popupMenu->addAction(KIcon("text-directory"), "Send File...");
          connect(sendFileAction, SIGNAL(triggered(bool)), this, SLOT(slotSendFile(bool)));
+
+         sendNoteAction = popupMenu->addAction(KIcon("knotes"), "Send KNote");
+         connect(sendNoteAction, SIGNAL(triggered(bool)), this, SLOT(slotDefineNote(bool)));
+
 /*
          sendDirAction = popupMenu->addAction(KIcon("inode-directory"), "Send Directory...");
          connect(sendDirAction, SIGNAL(triggered(bool)), this, SLOT(slotSendDir(bool)));
 */
 	 sendClipMenu = popupMenu->addMenu(KIcon("klipper"),"Send Clipboard");
+ 	 connect(sendClipMenu, SIGNAL(triggered(QAction*)), this, SLOT(slotSendClipEntry(QAction*)));
 	 addClipEntries();
+	
+	 if (buddyRunsHttp(buddyItem)){
+		 visitUrl = popupMenu->addAction(KIcon("network"), "Published Folder");
+        	 connect(visitUrl, SIGNAL(triggered(bool)), this, SLOT(slotShowUrl(bool)));
+	 }
 
 //	 getClipAction = popupMenu->addAction(KIcon("klipper"), "Get Clipboard");
 //       connect(getClipAction, SIGNAL(triggered(bool)), this, SLOT(slotGetClip(bool)));
 
          popupMenu->exec(QCursor::pos());
 //       pictureButton->setMenu(popupMenu);
+	 connect(buddyListWidget, SIGNAL(itemClicked(QListWidgetItem*)),this,SLOT(slotPopupMenu(QListWidgetItem*)));
 
 }
 
@@ -246,15 +321,20 @@ void BuddyList::slotSendFile(bool ok)
 
 	 int currentIndex = buddyListWidget->row(current);
 	 BuddyContent* cBC = buddyVector->at(currentIndex);
-	 qDebug() << "current Buddy Content: user " << cBC->name;
-	 qDebug() << "current Buddy Content: SN " << cBC->SN;
+	 kDebug() << "current Buddy Content: user " << cBC->name;
+	 kDebug() << "current Buddy Content: SN " << cBC->SN;
 	
-	 QString fileName = QFileDialog::getOpenFileName(this, tr("Select File"),"./","*");
-	 sendHandler = new Sender(m_parent,cBC->hostname,cBC->port,m_userName);
-	 sendHandler->initFileSender(fileName,1);
-//	 connect(sendHandler, SIGNAL(requestFinished(int)), this, SLOT(slotRequestSend(int)));
-//	 connect(sendHandler, SIGNAL(requestFailed(QString)), this, SLOT(slotRequestFailed(QString)));
-	 sendHandler->sendFileRequest();
+	 QString fileName = KFileDialog::getOpenFileName(KUrl("./"),"*",this, tr("Select File"));
+	 if (!fileName.isEmpty()) {
+		 sendHandler = new Sender(m_parent,cBC->llname,m_hostname,cBC->port,m_userName);
+		 sendHandler->initFileSender(fileName,1);
+		 connect(sendHandler,SIGNAL(transferFinished()), this, SLOT(slotSendFinished())); 
+		 connect(sendHandler,SIGNAL(transferDenied()), this, SLOT(slotSendFinished()));
+
+	//	 connect(sendHandler, SIGNAL(requestFinished(int)), this, SLOT(slotRequestSend(int)));
+	//	 connect(sendHandler, SIGNAL(requestFailed(QString)), this, SLOT(slotRequestFailed(QString)));
+		 sendHandler->sendFileRequest();
+	}
 
 }
 
@@ -265,19 +345,49 @@ void BuddyList::slotSendClip(QListWidgetItem* buddyItem)
 	 buddyItem->setBackground(QColor("aliceblue"));
      	 buddyItem->setForeground(Qt::red);
 	 buddyListWidget->setEnabled(false);
-	 if (icqListWidget != 0)
-		icqListWidget->setEnabled(false);
+
+	 if (listWidgets != 0) {
+		QList<QListWidget*>::iterator acc;
+                for(acc = listWidgets->begin(); acc != listWidgets->end(); ++acc) {
+			(*acc) -> setEnabled(false);
+		}
+	}
 
 	 int currentIndex = buddyListWidget->row(buddyItem);
 	 BuddyContent* cBC = buddyVector->at(currentIndex);
 
-	 sendHandler = new Sender(m_parent,cBC->hostname,cBC->port,m_userName);
+	 sendHandler = new Sender(m_parent,cBC->llname,m_hostname,cBC->port,m_userName);
 	 sendHandler->initClipSender();
 	 sendHandler->sendClipRequest(m_clipEntry);
 	
 	 connect(sendHandler,SIGNAL(transferFinished()), this, SLOT(slotSendFinished()));
 	 connect(sendHandler,SIGNAL(transferDenied()), this, SLOT(slotSendFinished()));
+}
 
+void BuddyList::slotSendNote(QListWidgetItem* buddyItem)
+{
+	 disconnect(buddyListWidget, SIGNAL(itemClicked(QListWidgetItem*)),this,SLOT(slotSendNote(QListWidgetItem*)));
+
+	 buddyItem->setBackground(QColor("aliceblue"));
+     	 buddyItem->setForeground(Qt::red);
+	 buddyListWidget->setEnabled(false);
+
+	 if (listWidgets != 0) {
+		QList<QListWidget*>::iterator acc;
+                for(acc = listWidgets->begin(); acc != listWidgets->end(); ++acc) {
+			(*acc) -> setEnabled(false);
+		}
+	}
+
+	 int currentIndex = buddyListWidget->row(buddyItem);
+	 BuddyContent* cBC = buddyVector->at(currentIndex);
+
+	 sendHandler = new Sender(m_parent,cBC->llname,m_hostname,cBC->port,m_userName);
+	 sendHandler->initNoteSender();
+	 sendHandler->sendClipRequest(m_noteEntry);
+	
+	 connect(sendHandler,SIGNAL(transferFinished()), this, SLOT(slotSendFinished()));
+	 connect(sendHandler,SIGNAL(transferDenied()), this, SLOT(slotSendFinished()));
 }
 
 
@@ -288,13 +398,16 @@ void BuddyList::slotSendFileDirect(QListWidgetItem* buddyItem)
 	 buddyItem->setBackground(QColor("aliceblue"));
      	 buddyItem->setForeground(Qt::red);
 	 buddyListWidget->setEnabled(false);
-	 if (icqListWidget != 0)
-		icqListWidget->setEnabled(false);
+	 if (listWidgets != 0) {
+		QList<QListWidget*>::iterator acc;
+                for(acc = listWidgets->begin(); acc != listWidgets->end(); ++acc)
+			(*acc) ->setEnabled(false);
+	}
 
 	 int currentIndex = buddyListWidget->row(buddyItem);
 	 BuddyContent* cBC = buddyVector->at(currentIndex);
 
-	 sendHandler = new Sender(m_parent,cBC->hostname,cBC->port,cBC->name);
+	 sendHandler = new Sender(m_parent,cBC->llname,m_hostname,cBC->port,cBC->name);
 	 sendHandler->initFileSender(m_fileName,1);
 	 sendHandler->sendFileRequest();
 	
@@ -303,15 +416,22 @@ void BuddyList::slotSendFileDirect(QListWidgetItem* buddyItem)
 
 }
 
-void BuddyList::slotSendFileDirectICQ(QListWidgetItem* buddyItem)
+void BuddyList::slotSendFileDirectKopete(QListWidgetItem* buddyItem)
 {
-	
-	disconnect(icqListWidget, SIGNAL(itemClicked(QListWidgetItem*)),this,SLOT(slotSendFileDirectICQ(QListWidgetItem*)));
+	 if (listWidgets != 0) {
+		QList<QListWidget*>::iterator acc;
+                for(acc = listWidgets->begin(); acc != listWidgets->end(); ++acc)
+			disconnect(*acc, SIGNAL(itemClicked(QListWidgetItem*)),this,SLOT(slotSendFileDirectKopete(QListWidgetItem*)));
+	}
+
 	buddyItem->setBackground(QColor("aliceblue"));
         buddyItem->setForeground(Qt::red);
 	buddyListWidget->setEnabled(false);
-	if (icqListWidget != 0)
-		icqListWidget->setEnabled(false);
+	if (listWidgets != 0) {
+		QList<QListWidget*>::iterator acc;
+                for(acc = listWidgets->begin(); acc != listWidgets->end(); ++acc)
+			(*acc) ->setEnabled(false);
+	}
 
         QString displayName = buddyItem->text();
 	
@@ -362,7 +482,7 @@ void BuddyList::addClipEntries()
 	QDBusInterface* interface = new QDBusInterface(service,path,service2,dbusconn);
 	QDBusReply<QStringList> reply = interface->call(method);
 	
-//	qDebug() << "klipper reply: " << reply.value();
+//	kDebug() << "klipper reply: " << reply.value();
 	QStringList clipList = reply.value();
 
 	for (int i=0; i < clipList.size(); i++){
@@ -378,38 +498,75 @@ void BuddyList::addClipEntries()
 		
 	}
 
- 	connect(sendClipMenu, SIGNAL(triggered(QAction*)), this, SLOT(slotSendClipEntry(QAction*)));
-
 }
 
 void BuddyList::slotSendClipEntry(QAction* action)
 {
+ 	disconnect(sendClipMenu, SIGNAL(triggered(QAction*)), this, SLOT(slotSendClipEntry(QAction*)));
+	m_clipEntry = action->toolTip();
 	QListWidgetItem* current = buddyListWidget->selectedItems().at(0);
 	slotSendClip(current);
 
 }
 
+void BuddyList::slotDefineNote(bool /*val*/)
+{
+ 	disconnect(sendClipMenu, SIGNAL(triggered(QAction*)), this, SLOT(slotSendClipEntry(QAction*)));
+        if (m_dialog == 0) {
+            kDebug() << "Creating Note editor";
+            m_dialog = new KDialog;
+            m_dialog->setCaption( i18n("Send KNote") );
+            noteEdit.setupUi(m_dialog->mainWidget());
+            m_dialog->setButtons( KDialog::None );
+            connect(noteEdit.sendButton,SIGNAL(clicked()),this,SLOT(slotNoteDefined()));
+            connect(noteEdit.cancelButton,SIGNAL(clicked()),m_dialog,SLOT(close()));
+        }
+        m_dialog->show();
+}
+
+void BuddyList::slotNoteDefined()
+{
+    m_noteEntry = noteEdit.textEdit->toPlainText();
+    QListWidgetItem* current = buddyListWidget->selectedItems().at(0);
+    delete m_dialog;
+    m_dialog = 0;
+    slotSendNote(current);
+}
+
 void BuddyList::slotSendFinished()
 {
 	disconnect(sendHandler,SIGNAL(transferFinished()), this, SLOT(slotSendFinished()));
 	disconnect(sendHandler,SIGNAL(transferDenied()), this, SLOT(slotSendFinished()));
 	disconnect(buddyListWidget, SIGNAL(itemClicked(QListWidgetItem*)),this,SLOT(slotSendFileDirect(QListWidgetItem*)));
 	disconnect(buddyListWidget, SIGNAL(itemClicked(QListWidgetItem*)),this,SLOT(slotSendClip(QListWidgetItem*)));
-	if (icqListWidget != 0) {
-		disconnect(icqListWidget, SIGNAL(itemClicked(QListWidgetItem*)),this,SLOT(slotSendFileDirectICQ(QListWidgetItem*)));
+	disconnect(buddyListWidget, SIGNAL(itemClicked(QListWidgetItem*)),this,SLOT(slotSendNote(QListWidgetItem*)));
+	if (listWidgets != 0) {
+		QList<QListWidget*>::iterator acc;
+                for(acc = listWidgets->begin(); acc != listWidgets->end(); ++acc)
+			disconnect(*acc, SIGNAL(itemClicked(QListWidgetItem*)),this,SLOT(slotSendFileDirectKopete(QListWidgetItem*)));
 	}
+
 	sendHandler->deleteLater();
-	qDebug() << "sendHandler deleted";
+	kDebug() << "sendHandler deleted";
+	m_clipEntry = "";
+        m_noteEntry = "";
 	
 	close();
 
 }
 
 
-void BuddyList::checkICQStatus()
+void BuddyList::checkKopeteStatus()
 {
-	if (icqListWidget)
-		tabWidget->removeTab(1);
+	if (listWidgets) {
+		kDebug() << "Anzahl in listWidgets " << listWidgets->count();
+
+		for(int i =1 ; i <= listWidgets->count(); i++) {
+			tabWidget->removeTab(1);
+		}
+		listWidgets->clear();
+	} else
+		listWidgets = new QList<QListWidget*>;
 
 	dbus = new QDBusConnection("dbus");
         QDBusConnection dbusconn = dbus->connectToBus(QDBusConnection::SessionBus, "dbus");
@@ -423,28 +580,39 @@ void BuddyList::checkICQStatus()
         QDBusReply<QStringList> reply = interface->call(methodAccount);
 	if (reply.isValid()) {	
 		QStringList accountList = reply.value();
-
+		QStringList protoList;
+		protoList << "ICQ" << "Jabber";
 		for (int i = 0; i < accountList.size(); i++)
 		{
-			QDBusReply<bool> reply1 = interface->call(isConnected,"ICQ",accountList.at(i));
-			if (reply1.value() == true) {
-				icqID = accountList.at(i);
-				icqListWidget = new QListWidget();
-				tabWidget->addTab(icqListWidget, SmallIcon("licq"),"Kopete-ICQ");
-				fillIcqTab();
-				break;
+			foreach(QString proto,protoList) {
+				QDBusReply<bool> reply1 = interface->call(isConnected,proto,accountList.at(i));
+				if (reply1.value() == true) {
+					ID = accountList.at(i);
+					kopeteListWidget = new QListWidget();
+					listWidgets->append(kopeteListWidget);
+					if (proto == "ICQ") 
+							tabWidget->addTab(kopeteListWidget, KIcon("licq"), QString(proto));
+					else if(proto == "Jabber")
+							tabWidget->addTab(kopeteListWidget, KIcon("jabber_protocol"), QString(proto));
+					
+
+					fillKopeteTab(proto);
+				}
 			}
+		
+			kDebug() << "Kopete Online Account found = "  << ID;
 		}
 		
-		qDebug() << "ICQ ID = "  << icqID;
+
 	}
 }
 
 
-void BuddyList::fillIcqTab()
+void BuddyList::fillKopeteTab(QString proto)
 {
 
-	icqListWidget->clear();
+	
+	kopeteListWidget->clear();
 	
 	dbus = new QDBusConnection("dbus");
         QDBusConnection dbusconn = dbus->connectToBus(QDBusConnection::SessionBus, "dbus");
@@ -458,27 +626,28 @@ void BuddyList::fillIcqTab()
 	
         QStringList contactList = reply.value();
 
-	icqListWidget->setMouseTracking(true);
-	icqListWidget->setSelectionRectVisible(false);
-	icqListWidget->setAutoFillBackground(false);
-	icqListWidget->setViewMode(QListView::IconMode);
-	icqListWidget->setResizeMode(QListView::Adjust);
-	icqListWidget->setEnabled(true);
+	kopeteListWidget->setMouseTracking(true);
+	kopeteListWidget->setSelectionRectVisible(false);
+	kopeteListWidget->setAutoFillBackground(false);
+	kopeteListWidget->setViewMode(QListView::IconMode);
+	kopeteListWidget->setResizeMode(QListView::Adjust);
+	kopeteListWidget->setEnabled(true);
+	kopeteListWidget->setDragEnabled(false);
 
 	for (int i = 0; i < contactList.size(); i++)
 	{
 		QStringList contactInfo = contactList.at(i).split(":");
-		if (contactInfo.at(0) == "ICQProtocol") {
+		if (contactInfo.at(0) == proto + "Protocol") {
 			QString contactID = contactInfo.at(2);
 			QString contactName = getContactName(contactID);
 			if (isOnline(contactName)) {
-				buddy = new QListWidgetItem(KIcon("user"), QString(contactName),icqListWidget);
-				icqListWidget->addItem(buddy);
+				buddy = new QListWidgetItem(KIcon("user-identity"), QString(contactName),kopeteListWidget);
+				kopeteListWidget->addItem(buddy);
 			}
 		}
 	}
 
-	connect(icqListWidget, SIGNAL(itemEntered(QListWidgetItem*)),this,SLOT(slotItemEntered(QListWidgetItem*)));
+	connect(kopeteListWidget, SIGNAL(itemEntered(QListWidgetItem*)),this,SLOT(slotItemEntered(QListWidgetItem*)));
 }
 
 
@@ -518,3 +687,31 @@ bool BuddyList::isOnline(QString name)
 	return status;
 }
 
+void BuddyList::slotShowUrl(bool)
+{
+	 QListWidgetItem* current = buddyListWidget->selectedItems().at(0);
+ 	 current->setBackground(QColor("aliceblue"));
+     	 current->setForeground(Qt::red);
+
+	 int currentIndex = buddyListWidget->row(current);
+	 BuddyContent* cBC = buddyVector->at(currentIndex);
+
+	 KRun::runUrl(KUrl(QString("http://" + cBC->http)), "text/html", 0);
+}
+
+bool BuddyList::buddyRunsHttp(QListWidgetItem* buddy)
+{
+	 int currentIndex = buddyListWidget->row(buddy);
+	 BuddyContent* cBC = buddyVector->at(currentIndex);
+ 	 kDebug() << "llname: " << cBC->SN;
+	 QStringList tmpList = httpList.keys();
+	 foreach(QString tmp,tmpList) {
+		kDebug() << "Http Service iterator: " << tmp;
+		 if (cBC->SN.split("@").at(1) == tmp){
+			cBC->http = httpList.value(tmp);
+			return true;
+		}
+	 }
+	 return false;
+}
+
